@@ -28,9 +28,12 @@
 //! ```
 //!
 //! ### Test that `cargo miri test -q` runs successfully and has expected stdout and empty stderr without normalization
-//! ```
+#![cfg_attr(windows, doc = "```ignore")] // FIXME: Fails with strange DLL error.
+#![cfg_attr(not(windows), doc = "```")]
 //! # use tryrun::prelude::*;
 //! Command::cargo_miri("test")
+//! #    .env_remove("LD_LIBRARY_PATH")
+//! #    .env_remove("DYLD_FALLBACK_LIBRARY_PATH")
 //!     .args(&["-q", "--lib", "--target-dir=target/miri"])
 //!     .run_pass(OutputStr::stdout("tests/ui/cargo_miri_test.stdout"), normalize::noop());
 //! ```
@@ -145,7 +148,7 @@ pub trait Normalizer {
     /// # use tryrun::prelude::*;
     /// struct DefaultNormalizer;
     /// impl Normalizer for DefaultNormalizer {}
-    /// assert_eq!(DefaultNormalizer.normalize_stdout(&mut b"ar".to_vec()), b"ar");
+    /// assert_eq!(DefaultNormalizer.normalize_stderr(&mut b"ar".to_vec()), b"ar");
     /// ```
     #[inline(always)]
     fn normalize_stderr<'a>(&mut self, stderr: &'a mut Vec<u8>) -> &'a [u8] {
@@ -832,10 +835,14 @@ mod tests {
     // All `cargo miri` invocations have to be placed only here, since running them in parallel
     // may result in "Blocking waiting on file lock of ... sysroot" message.
     #[test]
+    #[cfg(not(windows))] // FIXME: Fails with strange DLL error.
     #[cfg_attr(miri, ignore)]
     fn cargo_miri() {
         let mut cargo_miri = Command::cargo_miri("test");
-        cargo_miri.args(&["-q", "--release", "--lib", "--target-dir=target/miri"]);
+        cargo_miri
+            .env_remove("LD_LIBRARY_PATH")
+            .env_remove("DYLD_FALLBACK_LIBRARY_PATH")
+            .args(&["-q", "--release", "--lib", "--target-dir=target/miri"]);
         if cfg!(release) {
             cargo_miri.run_fail(
                 OutputStr::stderr("tests/ui/cargo_miri_release.stderr"),
